==> hs-haskell-src-exts-1.13.5_2.txz: usr/local/lib/cabal/ghc-7.6.3/haskell-src-exts-1.13.5/register.sh <==
#!/bin/sh
echo 'name: haskell-src-exts
version: 1.13.5
id: haskell-src-exts-1.13.5-d9af10a8ad8edebf2d35eb99eb803433

license: BSD3
copyright:
maintainer: Niklas Broberg <niklas.broberg@chalmers.se>
stability: Stable
homepage: http://code.haskell.org/haskell-src-exts
package-url:
synopsis: Manipulating Haskell source: abstract syntax, lexer, parser, and pretty-printer
description: Haskell-Source with Extensions (HSE, haskell-src-exts)
             is an extension of the standard haskell-src package,
             and handles most registered syntactic extensions to Haskell, including:
             .
             * Multi-parameter type classes with functional dependencies
             .
             * Indexed type families (including associated types)
             .
             * Empty data declarations
             .
             * GADTs
             .
             * Implicit parameters
             .
             * Template Haskell
             .
             and a few more. All extensions implemented in GHC are supported.
             Apart from these standard extensions,
             it also handles regular patterns as per the HaRP extension
             as well as HSX-style embedded XML syntax.
category: Language
author: Niklas Broberg
exposed: True
exposed-modules: Language.Haskell.Exts Language.Haskell.Exts.Lexer
                 Language.Haskell.Exts.Parser Language.Haskell.Exts.Pretty
                 Language.Haskell.Exts.Syntax Language.Haskell.Exts.Extension
                 Language.Haskell.Exts.Build Language.Haskell.Exts.Fixity
                 Language.Haskell.Exts.Comments Language.Haskell.Exts.SrcLoc
                 Language.Haskell.Exts.Annotated
                 Language.Haskell.Exts.Annotated.Syntax
                 Language.Haskell.Exts.Annotated.Fixity
                 Language.Haskell.Exts.Annotated.Build
                 Language.Haskell.Exts.Annotated.ExactPrint
                 Language.Haskell.Exts.Annotated.Simplify
hidden-modules: Language.Haskell.Exts.ExtScheme
                Language.Haskell.Exts.ParseMonad Language.Haskell.Exts.ParseSyntax
                Language.Haskell.Exts.InternalLexer
                Language.Haskell.Exts.ParseUtils
                Language.Haskell.Exts.InternalParser
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.6.3/haskell-src-exts-1.13.5
library-dirs: /usr/local/lib/cabal/ghc-7.6.3/haskell-src-exts-1.13.5
              /usr/local/lib
hs-libraries: HShaskell-src-exts-1.13.5
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: array-0.4.0.1-3b78425c10ff2dad7acf7e8c8ae014c3
         base-4.6.0.1-f7bdc8987bd5928e0ee6e8cc8b246a88
         cpphs-1.16-702db2d1d12c34f35eea74b6f0cf6aa5
         pretty-1.1.1.0-66181c695e6a2e173ba2088cf55cc396
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.6.3/haskell-src-exts-1.13.5/html/haskell-src-exts.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.6.3/haskell-src-exts-1.13.5/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> hs-haskell-src-exts-1.15.0.1_1.txz: usr/local/lib/cabal/ghc-7.8.3/haskell-src-exts-1.15.0.1/register.sh <==
#!/bin/sh
export PATH='/usr/local/libexec/ccache:/sbin:/bin:/usr/sbin:/usr/bin:/usr/games:/usr/local/sbin:/usr/local/bin:/root/bin'
echo 'name: haskell-src-exts
version: 1.15.0.1
id: haskell-src-exts-1.15.0.1-095483b4dfc53e4dffde0d68e3bff4ed

license: BSD3
copyright:
maintainer: Niklas Broberg <niklas.broberg@chalmers.se>
stability: Stable
homepage: https://github.com/haskell-suite/haskell-src-exts
package-url:
synopsis: Manipulating Haskell source: abstract syntax, lexer, parser, and pretty-printer
description: Haskell-Source with Extensions (HSE, haskell-src-exts)
             is an extension of the standard haskell-src package,
             and handles most registered syntactic extensions to Haskell, including:
             .
             * Multi-parameter type classes with functional dependencies
             .
             * Indexed type families (including associated types)
             .
             * Empty data declarations
             .
             * GADTs
             .
             * Implicit parameters
             .
             * Template Haskell
             .
             and a few more. All extensions implemented in GHC are supported.
             Apart from these standard extensions,
             it also handles regular patterns as per the HaRP extension
             as well as HSX-style embedded XML syntax.
category: Language
author: Niklas Broberg
exposed: True
exposed-modules: Language.Haskell.Exts Language.Haskell.Exts.Lexer
                 Language.Haskell.Exts.Parser Language.Haskell.Exts.Pretty
                 Language.Haskell.Exts.Syntax Language.Haskell.Exts.Extension
                 Language.Haskell.Exts.Build Language.Haskell.Exts.Fixity
                 Language.Haskell.Exts.Comments Language.Haskell.Exts.SrcLoc
                 Language.Haskell.Exts.Annotated
                 Language.Haskell.Exts.Annotated.Syntax
                 Language.Haskell.Exts.Annotated.Fixity
                 Language.Haskell.Exts.Annotated.Build
                 Language.Haskell.Exts.Annotated.ExactPrint
                 Language.Haskell.Exts.Annotated.Simplify
hidden-modules: Language.Haskell.Exts.ExtScheme
                Language.Haskell.Exts.ParseMonad Language.Haskell.Exts.ParseSyntax
                Language.Haskell.Exts.InternalLexer
                Language.Haskell.Exts.ParseUtils
                Language.Haskell.Exts.InternalParser
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.8.3/haskell-src-exts-1.15.0.1
library-dirs: /usr/local/lib/cabal/ghc-7.8.3/haskell-src-exts-1.15.0.1
              /usr/local/lib
hs-libraries: HShaskell-src-exts-1.15.0.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: array-0.5.0.0-98aa445e59f3eb0c886795ff07406d84
         base-4.7.0.1-812360bc88c9859b8259f0d90b6e2faa
         cpphs-1.18.5-21dcf22ce80159f3d8dc3f6f6d92b676
         ghc-prim-0.3.1.0-954cb57749cf319beafdc89b3415422c
         pretty-1.1.1.1-055fb3b6b88c48ad1bf91e5cf35828d1
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.8.3/haskell-src-exts-1.15.0.1/html/haskell-src-exts.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.8.3/haskell-src-exts-1.15.0.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
